/**
 * The MIT License (MIT)
 *
 * Copyright (C) 2013 Jaroslav Tulach <jaroslav.tulach@apidesign.org>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.apidesign.html.demo.chess;

import org.apidesign.html.demo.chess.BoardModel.ColorType;
import static org.testng.Assert.*;
import org.testng.annotations.Test;

/**
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
public class BoardModelTest {
    
    public BoardModelTest() {
    }


    @Test public void e2e4e7e6() {
        Board b = BoardModel.createBoard();
        assertEquals(b.getTurn(), ColorType.WHITE);
        
        Square e2 = BoardModel.findSquare(b, 'E', 2);
        assertNotNull(e2);
        BoardModel.selected(b, e2);
        assertEquals(BoardModel.findSelectedSquare(b), e2, "E2 is selected");
        
        Square e4 = BoardModel.findSquare(b, 'E', 4);
        assertNotNull(e4);
        
        BoardModel.selected(b, e4);
        
        assertNull(e2.getPiece(), "No pawn at e2");
        assertEquals(e4.getPiece(), BoardModel.PieceType.PAWN, "Pawn moved successfully");
        assertNull(BoardModel.findSelectedSquare(b), "No square selected");
        
        BoardModel.selected(b, e4);
        assertNull(BoardModel.findSelectedSquare(b), "No square selected, it is blacks turn");
        
        assertTrue(b.isBlackTurn(), "black's turn");
        
        
        Square e7 = BoardModel.findSquare(b, 'E', 7);
        BoardModel.selected(b, e7);
        assertEquals(BoardModel.findSelectedSquare(b), e7);
        
        BoardModel.selected(b, BoardModel.findSquare(b, 'E', 6));
        assertNull(e7.getPiece(), "Piece has been moved");
    }
    
    @Test public void cantSelectEmptySquare() {
        Board b = BoardModel.createBoard();
        Square e3 = BoardModel.findSquare(b, 'E', 3);
        assertNotNull(e3);
        BoardModel.selected(b, e3);
        assertNull(BoardModel.findSelectedSquare(b), "No square is selected");
    }

    @Test public void cantTakeOwnPiece() {
        Board b = BoardModel.createBoard();
        Square e1 = BoardModel.findSquare(b, 'E', 1);
        assertNotNull(e1);
        BoardModel.selected(b, e1);
        assertEquals(BoardModel.findSelectedSquare(b), e1, "E1 is selected");
        
        Square e2 = BoardModel.findSquare(b, 'E', 2);
        assertNotNull(e2);
        
        BoardModel.selected(b, e2);
        
        assertNotNull(e1.getPiece(), "King remains at e1");
        assertEquals(e2.getPiece(), BoardModel.PieceType.PAWN, "Pawn remains");
        assertEquals(BoardModel.findSelectedSquare(b), e2, "e2 now selected");
        
    }
    
}
