/**
 * The MIT License (MIT)
 *
 * Copyright (C) 2013 Jaroslav Tulach <jaroslav.tulach@apidesign.org>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.apidesign.html.demo.twitter;

import org.apidesign.html.demo.twitter.TwitterClient;
import java.util.List;
import net.java.html.json.Context;
import static org.testng.Assert.*;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

/** We can unit test the TwitterModel smoothly.
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
public class TwitterClientTest {
    private TwitterModel model;
    

    @BeforeMethod
    public void initModel() {
        model = new TwitterModel(Context.EMPTY);
    }

    @Test public void testIsValidToAdd() {
        model.setUserNameToAdd("Joe");
        Tweeters t = new Tweeters(Context.EMPTY);
        t.setName("test");
        model.getSavedLists().add(t);
        model.setActiveTweetersName("test");
        
        assertTrue(model.isUserNameToAddIsValid(), "Joe is OK");
        TwitterClient.addUser(model);
        assertFalse(model.isUserNameToAddIsValid(), "Can't add Joe for the 2nd time");
        assertEquals(t.getUserNames().size(), 0, "Original tweeters list remains empty");
        
        List<String> mod = model.getActiveTweeters();
        assertTrue(model.isHasUnsavedChanges(), "We have modifications");
        assertEquals(mod.size(), 1, "One element in the list");
        assertEquals(mod.get(0), "Joe", "Its name is Joe");
        
        assertSame(model.getActiveTweeters(), mod, "Editing list is the modified one");
        
        TwitterClient.saveChanges(model);
        assertFalse(model.isHasUnsavedChanges(), "Does not have anything to save");
        
        assertSame(model.getActiveTweeters(), mod, "Still editing the old modified one");
    }
    
    @Test public void httpAtTheEnd() {
        String res = TwitterClient.Twt.html("Ahoj http://kuk");
        assertEquals(res, "Ahoj <a href='http://kuk'>http://kuk</a>");
    }
}
